## [2.6.2](https://github.com/conekta/conekta-python/releases/tag/v2.6.3) - 2024-04-16
### Change
- Remove find line items when are creating an order

## [2.6.2](https://github.com/conekta/conekta-python/releases/tag/v2.6.2) - 2023-04-17
### Change
- Fix checkout errors
- Fix checkout tests
- Delete unused methods

## [2.6.1](https://github.com/conekta/conekta-python/releases/tag/v2.6.1) - 2020-12-30
### Change
- Fix indentation error

## [2.6.0](https://github.com/conekta/conekta-python/releases/tag/v2.6.0) - 2020-12-30
### Change
- Support creation of a payment link in the SDK.

## [2.5.1](https://github.com/conekta/conekta-python/releases/tag/v2.5.1) - 2019-12-31
### Change
- Adds message field for error object where it was previously missing

## [2.4.0](https://github.com/conekta/conekta-python/releases/tag/v2.4.0) - 2017-09-18
### Change
- Change httplib2 library for requests

## [2.3.4](https://github.com/conekta/conekta-python/releases/tag/v2.3.4) - 2017-06-08
### Feature
- Add void method for the class Order

## [2.3.3]() - 2017-03-24
### Fix
- Fix Subscriptions for Customer

## [2.3.0](https://github.com/conekta/conekta-python/releases/tag/2.3.0) - 2017-02-16
### Update
- Stable version for API 2.0.0
### Feature
- Order model, submodels and methods as well as enhanced errors and lists

## [2.1.0](https://github.com/conekta/conekta-python/releases/tag/2.1.0) - 2017-02-15
### Update
- Merging Api 2.0.0

## [2.0.0](https://github.com/conekta/conekta-python/releases/tag/v2.0) - 2017-01-03
### Feature
- Order's submodels added
### Change
- New Order flow
### Update	
- Supporting now API 2.0

## [1.2.0](https://github.com/conekta/conekta-python/releases/tag/v1.2) - 
### Feature
- Include locale support and python 3+

## [1.1.1](https://github.com/conekta/conekta-python/releases/tag/v1.1.1) - 2015-02-25
### Feature
- Include charge capture

## [1.1.0](https://github.com/conekta/conekta-python/releases/tag/v1.1.0) - 2014-04-22
### Feature
- Adding payee/payout objects

## [1.0.1](https://github.com/conekta/conekta-python/releases/tag/v1.0.1) - 2014-04-07
### Change
- Bundling source instead of platform specific versions

## [1.0.0](https://github.com/conekta/conekta-python/releases/tag/v1.0.0) - 2013-12-13
### Feature
- Includes subscriptions/tokenization/customers etc

## [0.9.0](https://github.com/conekta/conekta-python/releases/tag/v0.9.0) - 2013-11-15
### Feature
- Adding ssl certs to manifest

## [0.6.5](https://github.com/conekta/conekta-python/releases/tag/v0.6.5) - 2013-11-15
### Update
- Versioning v0.6.5

## [0.7.0](https://github.com/conekta/conekta-python/releases/tag/v0.7) - 2013-10-28
### Change
- Change in refunds, logs and object queries
- Breaking changes to object structure and usage

## [0.6.0](https://github.com/conekta/conekta-python/releases/tag/v0.6) - 2013-09-30
### Feature
- Get all events
